==> org.opennms.features.collection.api-20.0.0-20170223.004711-91-sources.jar: org/opennms/netmgt/collection/dto/NumericAttributeDTO.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.collection.dto;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;

import org.opennms.netmgt.collection.support.builder.NumericAttribute;

@XmlRootElement(name = "numeric-attribute")
@XmlAccessorType(XmlAccessType.NONE)
public class NumericAttributeDTO extends AttributeDTO {

    @XmlAttribute(name="value")
    private Number value;

    public NumericAttributeDTO() { }

    public NumericAttributeDTO(NumericAttribute attribute) {
        super(attribute);
        this.value = attribute.getNumericValue();
    }

    public NumericAttribute toAttribute() {
        return new NumericAttribute(getGroup(), getName(), value, getType(), getIdentifier());
    }

}

==> org.opennms.features.collection.api-27.0.0-20200422.021918-17-sources.jar: org/opennms/netmgt/collection/dto/NumericAttributeDTO.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.collection.dto;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

import org.opennms.core.xml.NumberAdapter;
import org.opennms.netmgt.collection.support.builder.NumericAttribute;

@XmlRootElement(name = "numeric-attribute")
@XmlAccessorType(XmlAccessType.NONE)
public class NumericAttributeDTO extends AttributeDTO {

    @XmlAttribute(name="value")
    @XmlJavaTypeAdapter(NumberAdapter.class)
    private Number value;

    public NumericAttributeDTO() { }

    public NumericAttributeDTO(NumericAttribute attribute) {
        super(attribute);
        this.value = attribute.getNumericValue();
    }

    public NumericAttribute toAttribute() {
        return new NumericAttribute(getGroup(), getName(), value, getType(), getIdentifier());
    }

}
